Obtain Coefficients from Scaled SVD of OCED Labour Force Participation Data
coef_lfp.RdObtain coefficients from a scaled SVD of OCED labour force participation data downloaded from the OECD Data Explorer. The coefficients are a scaled version of the \(U\) matrix from the SVD.
Truncation and transformation
Reported proportions outside (eps, 1-eps)
are shifted to eps or 1-eps, and
all values are logit-transformed,
before the SVD is applied.
See also
data_ssvd_lfp()Put OECD labour force participation data into the format required by thessvd()function in bagetidy_lfp()Format OECD labour force participation data into a tidy data frame.
Examples
coef_lfp(oecd_lfp_subset)
#> # A tibble: 2,235 × 5
#> sex country time component coef
#> <chr> <chr> <int> <chr> <dbl>
#> 1 Female AUS 2010 Component 1 -0.717
#> 2 Female AUS 2011 Component 1 -0.675
#> 3 Female AUS 2012 Component 1 -0.681
#> 4 Female AUT 2010 Component 1 0.410
#> 5 Female AUT 2011 Component 1 0.496
#> 6 Female AUT 2012 Component 1 0.593
#> 7 Female BEL 2010 Component 1 0.777
#> 8 Female BEL 2011 Component 1 0.537
#> 9 Female BEL 2012 Component 1 0.667
#> 10 Female BGR 2010 Component 1 0.808
#> # ℹ 2,225 more rows